@@ -13,10 +13,11 @@ sub stats($) { return {
 	"handle" => new WWW::Shopify::Field::String(),
 	"updated_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
 	"published_at" => new WWW::Shopify::Field::Date(min => '2010-01-01 00:00:00', max => 'now'),
-	"id" => new WWW::Shopify::Field::Identifier::String(),
+	"id" => new WWW::Shopify::Field::Identifier(),
 	"sort_order" => new WWW::Shopify::Field::String::Enum(["manual", "automatic"]),
 	"template_suffix" => new WWW::Shopify::Field::String(),
-	"metafields" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Metafield") };
+	"metafields" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Metafield"),
+	"products" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Product") }
 }
 
 eval(WWW::Shopify::Model::Item::generate_accessors(__PACKAGE__)); die $@ if $@;
